import {JetView} from "webix-jet";
import InfoView from "views/info";

export default class StartView extends JetView{
	config(){
		const ui = {
			rows:[
				{
					view:"tabbar",
					localId:"tabs",
					options:[
						{id:"start", value:"Start page"}
					],
					on:{
						onBeforeTabClose: id => this.CloseTab(id),
						onChange: id => this.ShowTab(id)
					}
				},
				{
					view:"multiview",
					localId:"cells",
					animate:false,
					cells:[
						{ localId:"start", rows:[
							{template:"Clients", type:"header"},
							{
								view:"datatable",
								localId:"grid",
								select:true,
								autoConfig:true, 
								data:[
									{ name:"Person 1", email:"test@test.com" },
									{ name:"Person 2", email:"test@test.com" },
									{ name:"Person 3", email:"test@test.com" },
								],
								on:{
									onAfterSelect: id => this.ShowTab(id)
								}
							}
						]}
					]
				}
			]
		};

		return ui;
	}
	init(){
		this.tabbar = this.$$("tabs");
		this.cells = this.$$("cells");
		this.grid = this.$$("grid");
	}
	CloseTab(id){
		webix.confirm("Are you sure?").then(() => {
			this.tabbar.removeOption(id);
			const view = this.$$(id);
			if (id)	this.cells.removeView(view);
		});
		return false;
	}
	ShowTab(id){
		id = id+"";
		const tab = this.tabbar.getOption(id);
		// assuming that tabs and views are always linked, only tab is checked
		if (!tab){
			this.AddTab(id);
		}
		this.tabbar.setValue(id);
		this.$$(id).show();
	}
	AddTab(id){
		const data = this.grid.getItem(id);
		this.tabbar.addOption({
			id,
			close: true,
			value: data.name
		});
		// a reguler layout with a static Jet subview inside
		this.cells.addView({
			localId: id,
			rows:[{
				$subview: new InfoView(this.app, "subview"+id, { data })
			}]
		});
	}
}